TimelineCarousel class
A beautiful timeline carousel widget that displays items in a timeline format
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TimelineCarousel
Constructors
-
TimelineCarousel({Key? key, required List<
TimelineItem> items, TimelineCarouselController? controller, double height = 300, bool showArrows = true, bool autoPlay = false, Duration autoPlayInterval = const Duration(seconds: 3), Color timelineColor = Colors.blue, Color activeDotColor = Colors.blue, Color inactiveDotColor = Colors.grey, double lineThickness = 2.0, double dotSize = 12.0, bool showTimeline = true, Curve animationCurve = Curves.easeInOut, Duration animationDuration = const Duration(milliseconds: 300), ValueChanged<int> ? onItemChanged, EdgeInsetsGeometry padding = const EdgeInsets.all(16.0), Color? backgroundColor, double cardBorderRadius = 12.0, List<BoxShadow> ? cardShadow, bool timelineOnRight = false}) -
const
Properties
- activeDotColor → Color
-
Active dot color
final
- animationCurve → Curve
-
Animation curve
final
- animationDuration → Duration
-
Animation duration
final
- autoPlay → bool
-
Whether to enable auto-play
final
- autoPlayInterval → Duration
-
Auto-play interval
final
- backgroundColor → Color?
-
Background color of the carousel
final
- cardBorderRadius → double
-
Border radius of timeline cards
final
-
cardShadow
→ List<
BoxShadow> ? -
Shadow for timeline cards
final
- controller → TimelineCarouselController?
-
Controller for the carousel
final
- dotSize → double
-
Dot size
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
Height of the carousel
final
- inactiveDotColor → Color
-
Inactive dot color
final
-
items
→ List<
TimelineItem> -
List of timeline items to display
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lineThickness → double
-
Timeline line thickness
final
-
onItemChanged
→ ValueChanged<
int> ? -
Callback when item changes
final
- padding → EdgeInsetsGeometry
-
Padding around the carousel
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showArrows → bool
-
Whether to show navigation arrows
final
- showTimeline → bool
-
Whether to show the timeline
final
- timelineColor → Color
-
Timeline line color
final
- timelineOnRight → bool
-
Whether the timeline should be on the left or right
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TimelineCarousel> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited